Changelog
=========


1.0.0rc2 (2021-03-11)
---------------------

- Added a ``tracking_disabled`` context manager to disable tracking the last modifier
  [ale-rt]

1.0.0rc1 (2021-02-18)
---------------------

- Initial release.
  [ale-rt]
